pilas.evento.ProxyMetodo

Package pilas :: Module evento :: Class ProxyMetodo |
[hide private]
[frames] | no frames]

# Class ProxyMetodo

source code

    object --+
             |
            ProxyMetodo

Permite asociar funciones pero con referencias débiles, que no incrementan el contador de referencias.

Este proxy funciona tanto con funciones como con métodos enlazados a un objeto.

Organization: IBM Corporation

Copyright: Copyright (c) 2005, 2006 IBM Corporation

License: The BSD License

Instance Methods | [hide private]
__init__(self, cb, id) x.__init__(...) initializes x; see help(type(x)) for signature | source code
__call__(self, **evento) | source code
__eq__(self, other) | source code
__ne__(self, other) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, cb, id) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)